@@ -23,7 +23,6 @@
 
 import argparse
 import enum
-from glob import glob
 import hashlib
 import json
 import os
@@ -33,6 +32,7 @@ import sys
 import tempfile
 import urllib.parse
 import urllib.request
+from glob import glob
 
 import attrs
 import bibtexparser
@@ -102,7 +102,10 @@ RETURN_CODE_BROKEN = 2
 def main():
     fns_aux, config, verbose = parse_args()
     if len(fns_aux) == 0:
-        fns_aux = [fn for fn in glob("**/*.aux", recursive=True)]
+        # Only select aux files for which corresponding tex files exist.
+        fns_aux = [
+            fn for fn in glob("**/*.aux", recursive=True) if os.path.isfile(fn[:-4] + ".tex")
+        ]
     first = True
     for fn_aux in fns_aux:
         if first:
@@ -135,7 +138,6 @@ def process_aux(fn_aux, config, verbose):
             print("📂 Loading", fn_aux)
         citations, fns_bib = parse_aux(fn_aux)
 
-
     if verbose:
         print(f"   Found {len(citations)} citations")
     citations = set(citations)
